@@ -79,6 +79,7 @@ static char msg1[20];
 const double rtty::SHIFT[] = {23, 85, 160, 170, 182, 200, 240, 350, 425, 850};
 const double rtty::BAUD[]  = {45, 45.45, 50, 56, 75, 100, 110, 150, 200, 300};
 const int	rtty::BITS[]  = {5, 7, 8};
+const int	rtty::numshifts = (int)(sizeof(SHIFT) / sizeof(*SHIFT));
 
 void rtty::tx_init(SoundBase *sc)
 {
@@ -184,6 +185,7 @@ rtty::~rtty()
 	if (space_filt) delete space_filt;
 	if (pipe) delete [] pipe;
 	if (dsppipe) delete [] dsppipe;
+	if (bits) delete bits;
 	delete m_Osc1;
 	delete m_Osc2;
 	delete m_SymShaper1;
@@ -213,8 +215,9 @@ void rtty::restart()
 {
 	double stl;
 
-	rtty_shift = shift = (progdefaults.rtty_shift >= 0 ?
+	rtty_shift = shift = (progdefaults.rtty_shift < numshifts ?
 				  SHIFT[progdefaults.rtty_shift] : progdefaults.rtty_custom_shift);
+printf("rtty_shift %.1f\n", shift);
 	rtty_baud = BAUD[progdefaults.rtty_baud];
 	nbits = rtty_bits = BITS[progdefaults.rtty_bits];
 	if (rtty_bits == 5)
@@ -228,7 +231,7 @@ void rtty::restart()
 			case 4 : rtty_parity = RTTY_PARITY_ONE; break;
 			default : rtty_parity = RTTY_PARITY_NONE; break;
 		}
-	rtty_stop = progdefaults.rtty_stop;
+	// (exists below already)  rtty_stop = progdefaults.rtty_stop;
 
 	txmode = LETTERS;
 	rxmode = LETTERS;
@@ -267,7 +270,7 @@ void rtty::restart()
 		snprintf(msg1, sizeof(msg1), "%-4.2f/%-4.0f", rtty_baud, rtty_shift);
 	put_Status1(msg1);
 	put_MODEstatus(mode);
-	for (int i = 0; i < MAXPIPE; i++) 
+	for (int i = 0; i < MAXPIPE; i++)
 		QI[i] = cmplx(0.0, 0.0);
 	sigpwr = 0.0;
 	noisepwr = 0.0;
@@ -474,7 +477,6 @@ bool rtty::rx(bool bit) // original modified for probability test
 			if (is_mark()) {
 				if ((metric >= progStatus.sldrSquelchValue && progStatus.sqlonoff) || !progStatus.sqlonoff) {
 					c = decode_char();
-
 					if( progdefaults.SynopAdifDecoding || progdefaults.SynopKmlDecoding ) {
 						if (c != 0 && c != '\r')  {
 							synop::instance()->add(c);
@@ -818,7 +820,7 @@ if (mnum < 2 * filter_length)
 				if (clear_zdata) {
 					clear_zdata = false;
 					Clear_syncscope();
-					for (int i = 0; i < MAXPIPE; i++) 
+					for (int i = 0; i < MAXPIPE; i++)
 						QI[i] = cmplx(0.0, 0.0);
 				}
 			}
@@ -841,8 +843,7 @@ double rtty::nco(double freq)
 {
 	phaseacc += TWOPI * freq / samplerate;
 
-	if (phaseacc > M_PI)
-		phaseacc -= TWOPI;
+	if (phaseacc > TWOPI) phaseacc -= TWOPI;
 
 	return cos(phaseacc);
 }
@@ -851,9 +852,7 @@ double rtty::FSKnco()
 {
 	FSKphaseacc += TWOPI * 1000 / samplerate;
 
-	if (FSKphaseacc > M_PI)
-
-		FSKphaseacc -= TWOPI;
+	if (FSKphaseacc > TWOPI) FSKphaseacc -= TWOPI;
 
 	return sin(FSKphaseacc);
 
@@ -1036,8 +1035,7 @@ void rtty::send_char(int c)
 			c = figures[c];
 		if (c)
 			put_echo_char(progdefaults.rx_lowercase ? tolower(c) : c);
-	} else if (c)
-		put_echo_char(c);
+	}
 }
 
 void rtty::send_idle()
@@ -1245,7 +1243,8 @@ Oscillator::Oscillator( double samplerate )
 double Oscillator::Update( double frequency )
 {
 	m_phase += frequency/m_samplerate * TWOPI;
-	if ( m_phase > M_PI ) m_phase -= TWOPI;
+	if ( m_phase > TWOPI ) m_phase -= TWOPI;
+
 	return ( sin( m_phase ) );
 }
 
@@ -1255,6 +1254,11 @@ SymbolShaper::SymbolShaper(double baud, double sr)
 	Preset( baud, sr );
 }
 
+SymbolShaper::~SymbolShaper()
+{
+	delete [] m_sinc_table;
+}
+
 void SymbolShaper::reset()
 {
 	m_State = false;
@@ -1287,7 +1291,8 @@ void SymbolShaper::Preset(double baud, double sr)
 
 // kill old sinc-table and get memory for the new one -----------------
 
-    delete [] m_sinc_table;
+	if (m_sinc_table)
+		delete [] m_sinc_table;
     m_sinc_table = new double[m_table_size];
 
 // set up the new sinc-table based on the new parameters --------------
@@ -1298,9 +1303,9 @@ void SymbolShaper::Preset(double baud, double sr)
         int const offset = m_table_size/2;
         double const T = sample_rate / (baud_rate*2.0); // symbol-length in samples
         double const t = (x-offset); // symbol-time relative to zero
-       
+
         m_sinc_table[x] = rcos( t, T, 1.0 );
-   
+
 // calculate integral
         sum += m_sinc_table[x];
     }
