@@ -36,13 +36,14 @@
 #include "waterfall.h"
 #include "digiscope.h"
 #include "globals.h"
-#include "mixer.h"
 #include "progress.h"
 #include "FreqControl.h"
 #include "flinput2.h"
 #include "flslider2.h"
 #include "psk_browser.h"
 #include "re.h"
+#include "smeter.h"
+#include "pwrmeter.h"
 
 extern fre_t seek_re;
 
@@ -61,6 +62,9 @@ extern Fl_Input2		*txtInpSeek;
 extern Fl_Box			*hideViewer;
 extern Fl_Group		*mvgroup;
 
+extern Fl_Group		*text_group;
+extern Fl_Group		*wefax_group;
+
 extern Panel			*text_panel;
 extern Fl_Box			*minbox;
 extern int				oix;
@@ -72,6 +76,8 @@ extern Fl_Counter2		*cntTxLevel;
 extern Fl_Button		*MODEstatus;
 extern Fl_Slider2		*sldrSquelch;
 extern Progress		*pgrsSquelch;
+extern Smeter			*smeter;
+extern PWRmeter		*pwrmeter;
 extern Fl_Button 		*btnMacro[];
 extern Fl_Button		*btnAltMacros1;
 extern Fl_Button		*btnAltMacros2;
@@ -118,10 +124,9 @@ extern Fl_Button		*qso_opPICK;
 extern Fl_Browser		*qso_opBrowser;
 
 extern Fl_Value_Slider2	*mvsquelch;
-extern Fl_Value_Slider2	*valRcvMixer;
-extern Fl_Value_Slider2	*valXmtMixer;
-extern Fl_Button			*btnAFC;
-extern Fl_Button			*btnSQL;
+extern Fl_Light_Button		*btnAFC;
+extern Fl_Light_Button		*btnSQL;
+extern Fl_Light_Button		*btnPSQL;
 extern Fl_Light_Button		*btnRSID;
 extern Fl_Light_Button		*btnTxRSID;
 extern Fl_Light_Button		*btnTune;
@@ -137,6 +142,7 @@ extern std::string		main_window_title;
 
 extern int Qwait_time;
 extern int Qidle_time;
+extern bool idling;
 
 extern void toggleRSID();
 
@@ -170,6 +176,7 @@ extern void set_phase(double phase, double quality, bool highlight);
 extern void set_rtty(double, double, double);
 extern void set_video(double *, int, bool = true);
 extern void set_zdata(cmplx *, int);
+extern void update_scope();
 
 extern void set_scope_xaxis_1(double y1);
 extern void set_scope_xaxis_2(double y2);
@@ -179,6 +186,7 @@ extern void set_scope_clear_axis();
 
 extern void set_CWwpm();
 extern void put_rx_char(unsigned int data, int style = FTextBase::RECV);
+extern void put_rx_processed_char(unsigned int data, int style = FTextBase::RECV);
 extern void put_sec_char( char chr );
 
 enum status_timeout {
@@ -219,6 +227,21 @@ extern bool que_ok;
 extern void post_queue_execute(void*);
 extern void queue_execute_after_rx(void*);
 
+extern time_t program_start_time;
+
+extern bool xmlrpc_address_override_flag;
+extern bool arq_address_override_flag;
+extern bool kiss_address_override_flag;
+extern std::string override_xmlrpc_address;
+extern std::string override_xmlrpc_port;
+extern std::string override_arq_address;
+extern std::string override_arq_port;
+extern std::string override_kiss_address;
+extern std::string override_kiss_io_port;
+extern std::string override_kiss_out_port;
+extern int override_kiss_dual_port_enabled;
+extern int override_data_io_enabled;
+
 extern int rxtx_charset;
 extern void put_rx_data(int *data, int len);
 
@@ -234,13 +257,14 @@ extern int  get_secondary_char();
 extern void put_echo_char(unsigned int data, int style = FTextBase::XMIT);
 extern char *get_rxtx_data();
 extern char *get_rx_data();
-extern char *get_tx_data(); 
+extern char *get_tx_data();
 
 extern void resetRTTY();
 extern void resetOLIVIA();
 extern void resetCONTESTIA();
 extern void resetTHOR();
 extern void resetDOMEX();
+extern void updatePACKET();
 extern void resetSoundCard();
 extern void restoreFocus(Fl_Widget* w = 0);
 extern void setReverse(int);
@@ -331,6 +355,10 @@ extern int  notch_frequency;
 extern void notch_on(int);
 extern void notch_off();
 
+// Set IO port
+extern void enable_kiss(void);
+extern void enable_arq(void);
+
 // thread terminators
 extern void ADIF_RW_close(void);
 extern void EQSL_close(void);
@@ -345,4 +373,8 @@ bool ask_dir_creation( const std::string & dir );
 
 extern void set_CSV(int how);
 
+extern void set_freq_control_lsd();
+
+extern void set_smeter_colors();
+
 #endif
