@@ -121,6 +121,14 @@ enum {
 	MODE_QPSK250,
 	MODE_QPSK500,
 
+	MODE_8PSK125,
+	MODE_8PSK250,
+	MODE_8PSK500,
+	MODE_8PSK1000,
+//	MODE_8PSK2000,
+	MODE_8PSK_FIRST = MODE_8PSK125,
+	MODE_8PSK_LAST = MODE_8PSK1000,
+
 	MODE_PSK125R,
 	MODE_PSK250R,
 	MODE_PSK500R,
@@ -164,6 +172,7 @@ enum {
 	MODE_THROB_FIRST = MODE_THROB1,
 	MODE_THROB_LAST = MODE_THROBX4,
 
+//	MODE_PACKET,
 // high speed && multiple carrier modes
 
 	MODE_4X_PSK63R,
@@ -203,6 +212,7 @@ enum {
 	MODE_SSB,
 	MODE_WWV,
 	MODE_ANALYSIS,
+	MODE_FFTSCAN,
 
 	NUM_MODES,
 	NUM_RXTX_MODES = NUM_MODES - 2
@@ -218,6 +228,7 @@ struct mode_info_t {
 	const char *pskmail_name;
 	const char *adif_name;
 	const char *vid_name;
+	const unsigned int iface_io; // Some modes are not usable for a given interface.
 };
 extern const struct mode_info_t mode_info[NUM_MODES];
 
