@@ -116,6 +116,7 @@ public:
 	/// Inlined const getters are faster and smaller.
 	trx_mode	get_mode() const { return mode; };
 	const char	*get_mode_name() const { return mode_info[get_mode()].sname;}
+	unsigned int iface_io() const { return mode_info[get_mode()].iface_io;}
 	virtual void	set_freq(double);
 	/// Inlining small formulas is still faster and shorter.
 	int		get_freq() const { return (int)( frequency + 0.5 ); }
@@ -138,7 +139,7 @@ public:
 	void		init_queues();
 
 	void		ModulateXmtr(double *, int);
-	void		ModulateStereo(double *, double *, int);
+	void		ModulateStereo(double *, double *, int, bool sample_flag = true);
 
 	void		videoText();
 	void		pretone();
@@ -162,6 +163,7 @@ public:
 	double		get_cwXmtWPM();
 	void		set_cwXmtWPM(double);
 	double		get_cwRcvWPM();
+
 	virtual	void		incWPM() {};
 	virtual void		decWPM() {};
 	virtual void		toggleWPM() {};
@@ -201,6 +203,10 @@ public:
 	void	cwid_sendtext (const std::string& s);
 	void	cwid();
 
+// for fft scan modem
+public:
+	virtual void	refresh_scope() {}
+
 // for noise tests
 private:
 	void	add_noise(double *, int);
@@ -223,6 +229,11 @@ public:
 	int  xmt_samples;
 	int  ovhd_samples;
 
+// analysis mode
+	virtual void start_csv() {}
+	virtual void stop_csv() {}
+	virtual int is_csv() { return true;}
+	virtual double track_freq() { return 0;}
 };
 
 extern modem *null_modem;
@@ -278,6 +289,12 @@ extern modem *qpsk125_modem;
 extern modem *qpsk250_modem;
 extern modem *qpsk500_modem;
 
+extern modem *_8psk125_modem;
+extern modem *_8psk250_modem;
+extern modem *_8psk500_modem;
+extern modem *_8psk1000_modem;
+extern modem *_8psk2000_modem;
+
 extern modem *psk125r_modem;
 extern modem *psk250r_modem;
 extern modem *psk500r_modem;
@@ -317,7 +334,7 @@ extern modem *psk500r_c3_modem;
 extern modem *psk500r_c4_modem;
 
 extern modem *rtty_modem;
-extern modem *pkt_modem;
+//extern modem *pkt_modem;
 
 extern modem *olivia_modem;
 extern modem *olivia_4_250_modem;
@@ -361,6 +378,7 @@ extern modem *throbx4_modem;
 
 extern modem *wwv_modem;
 extern modem *anal_modem;
+extern modem *fftscan_modem;
 extern modem *ssb_modem;
 
 
