@@ -82,11 +82,11 @@ using namespace std;
 
 
 const char *szBaudRates[] = {
-	"", 
+	"",
 	"300","600","1200","2400",
 	"4800","9600","19200","38400",
 	"57600","115200","230400","460800"};
-	
+
 const char *szBands[] = {
 	"",
 	"1830", "3580", "7030", "7070", "10138",
@@ -525,21 +525,13 @@ int configuration::setDefaults()
 
 	inpTTYdev->value(PTTdev.c_str());
 
-	if (chkUSEHAMLIBis) {
-		chkUSEHAMLIB->value(1);
-		chkUSERIGCAT->value(0);  chkUSEXMLRPC->value(0);
-	} else if (chkUSERIGCATis) {
-		chkUSERIGCAT->value(1);
-		chkUSEHAMLIB->value(0); chkUSEXMLRPC->value(0);
-	} else if (chkUSEXMLRPCis) {
-		chkUSEXMLRPC->value(1);
-		chkUSEHAMLIB->value(0); chkUSERIGCAT->value(0);
-	} else {
-		chkUSEHAMLIB->value(0); 
-		chkUSERIGCAT->value(0);
-		chkUSEHAMLIB->value(0);
-		chkUSEXMLRPC->value(0);
-	}
+	chkUSEHAMLIB->value(0);
+	chkUSERIGCAT->value(0);
+	chkUSEXMLRPC->value(0);
+	if (chkUSEHAMLIBis) chkUSEHAMLIB->value(1);
+	if (chkUSERIGCATis) chkUSERIGCAT->value(1);
+	if (chkUSEXMLRPCis) chkUSEXMLRPC->value(1);
+
 	if (!XmlRigFilename.empty()) readRigXML();
 
 	inpRIGdev->value(HamRigDevice.c_str());
@@ -569,14 +561,14 @@ int configuration::setDefaults()
 	cntSearchRange->value(SearchRange);
 	cntServerOffset->value(ServerOffset);
 	cntACQsn->value(ACQsn);
-			
+
 	btnCursorBWcolor->color(
 		fl_rgb_color(cursorLineRGBI.R, cursorLineRGBI.G, cursorLineRGBI.B) );
 	btnCursorCenterLineColor->color(
 		fl_rgb_color(cursorCenterRGBI.R, cursorCenterRGBI.G, cursorCenterRGBI.B) );
 	btnBwTracksColor->color(
 		fl_rgb_color(bwTrackRGBI.R, bwTrackRGBI.G, bwTrackRGBI.B) );
-				
+
 	cntCWweight->value(CWweight);
 	sldrCWxmtWPM->value(CWspeed);
 	cntCWdefWPM->value(defCWspeed);
@@ -596,10 +588,10 @@ int configuration::setDefaults()
 	cntPreTiming->value(CWpre);
 	cntPostTiming->value(CWpost);
 	btnCWID->value(CWid);
-			
+
 	listboxHellFont->index(feldfontnbr);
 	btnFeldHellIdle->value(HellXmtIdle);
-			
+
 	btnTxRSID->value(TransmitRSid);
 	btnRSID->value(rsid);
 	chkRSidWideSearch->value(rsidWideSearch);
@@ -698,7 +690,7 @@ Reset all options to their default values?\n\n\
 Reset options will take effect at the next start\n\
 Files: fldigi_def.xml and fldigi.prefs will be deleted!\n"), _("OK"), _("Cancel"), NULL) &&
 			Fl::event_key() != FL_Escape) {
-		if (!fl_choice2(_("Confirm RESET"), _("Yes"), _("No"), NULL) && 
+		if (!fl_choice2(_("Confirm RESET"), _("Yes"), _("No"), NULL) &&
 			Fl::event_key() != FL_Escape) {
 			reset();
 			atexit(reset);
@@ -721,8 +713,10 @@ void configuration::initInterface()
 // close down any possible rig interface threads
 #if USE_HAMLIB
 	hamlib_close();
+//		MilliSleep(100);
 #endif
 	rigCAT_close();
+//		MilliSleep(100);
 
 	RigCatCMDptt = btnRigCatCMDptt->value();
 	TTYptt = btnTTYptt->value();
@@ -757,7 +751,6 @@ void configuration::initInterface()
 
 	if (chkUSERIGCATis) { // start the rigCAT thread
 		if (rigCAT_init(true)) {
-			LOG_VERBOSE("%s", "using rigCAT");
 			wf->USB(true);
 			wf->setQSY(1);
 			riginitOK = true;
@@ -780,7 +773,6 @@ void configuration::initInterface()
 	}
 
 	if (riginitOK == false) {
-		LOG_VERBOSE("%s", "NO rig control");
 		rigCAT_init(false);
 		wf->USB(true);
 		wf->setQSY(0);
@@ -923,7 +915,7 @@ void configuration::testCommPorts()
 #    endif
 #  endif // __WOE32__
 
-			LOG_INFO("Found serial port %s", ttyname);
+			LOG_VERBOSE("Found serial port %s", ttyname);
 			inpTTYdev->add(ttyname);
 #  if USE_HAMLIB
 			inpRIGdev->add(ttyname);
@@ -937,7 +929,7 @@ void configuration::testCommPorts()
 			if ( !(stat(gbuf.gl_pathv[j], &st) == 0 && S_ISCHR(st.st_mode)) ||
 			     strstr(gbuf.gl_pathv[j], "modem") )
 				continue;
-			LOG_INFO("Found serial port %s", gbuf.gl_pathv[j]);
+			LOG_VERBOSE("Found serial port %s", gbuf.gl_pathv[j]);
 			inpTTYdev->add(gbuf.gl_pathv[j]);
 #  if USE_HAMLIB
 			inpRIGdev->add(gbuf.gl_pathv[j]);
