@@ -75,9 +75,6 @@ void loadBrowser(Fl_Widget *widget) {
 	w->add(_("<MYNAME>\tmy name"));
 	w->add(_("<MYQTH>\tmy QTH"));
 	w->add(_("<MYRST>\tmy RST"));
-	w->add(_("<ANTENNA>\tmy antenna"));
-	w->add(_("<BAND>\toperating band"));
-	w->add(LINE_SEP);
 	w->add(_("<VER>\tFldigi version"));
 
 	w->add(LINE_SEP);
@@ -92,7 +89,7 @@ void loadBrowser(Fl_Widget *widget) {
 	w->add(_("<NXTNBR>\tnext QSO rec #"));
 	w->add(_("<MAPIT>\tmap on google"));
 	w->add(_("<MAPIT:adr/lat/loc>\tmap by value"));
- 
+
 	w->add(LINE_SEP);
 	w->add(_("<CLRRX>\tclear RX pane"));
 	w->add(_("<CLRTX>\tclear TX pane"));
@@ -147,15 +144,15 @@ void loadBrowser(Fl_Widget *widget) {
 	w->add(_("<GOFREQ:NNNN>\tmove to freq NNNN Hz"));
 	w->add(_("<QSYTO>\tleft-clk QSY button"));
 	w->add(_("<QSYFM>\tright-clk QSY button"));
+	w->add(_("<QSY:FFF.F[:NNNN]>\tqsy to kHz, Hz"));
+	w->add(_("<QSY+:+/-n.nnn>\tincr/decr xcvr freq"));
+	w->add(_("<RIGMODE:mode>\tvalid xcvr mode"));
+	w->add(_("<FILWID:width>\tvalid xcvr filter width"));
+	w->add(_("<FOCUS>\trig freq has kbd focus"));
 
 	w->add(LINE_SEP);
 	w->add(_("<QRG:text>\tinsert QRG into Rx text"));
 
-	w->add(LINE_SEP);
-	w->add(_("<QSY:FFF.F[:NNNN]>\tqsy to kHz, Hz"));
-	w->add(_("<RIGMODE:mode>\tvalid xcvr mode"));
-	w->add(_("<FILWID:width>\tvalid xcvr filter width"));
-
 	w->add(LINE_SEP);
 	w->add(_("<FILE:>\tinsert text file"));
 	w->add(_("<IMAGE:>\tinsert MFSK image"));
@@ -200,7 +197,7 @@ void loadBrowser(Fl_Widget *widget) {
 	w->add(_("<SAVE>\tsave current macro file"));
 
 	w->add(LINE_SEP);
-	w->add(_("<COMMENT:text>\tuntransmitted comment"));
+	w->add(_("<COMMENT:comment text>\tignore all comment text"));
 
 	w->add(LINE_SEP);
 	w->add(_("<CPS_TEST>\tmodem timing test internal string"));
@@ -212,6 +209,8 @@ void loadBrowser(Fl_Widget *widget) {
 	w->add(_("<WAV_FILE:>\tWAV file; spec' file"));
 	w->add(_("<WAV_STRING:s>\tWAV file; string 's'"));
 
+	w->add(LINE_SEP);
+	w->add(_("<CSV:on|off|t>\tAnalysis CSV on,off,toggle"));
 	w->add(LINE_SEP);
 	assert(MODE_CONTESTIA < MODE_OLIVIA);
 	char s[256];
@@ -293,7 +292,7 @@ void cbMacroEditOK(Fl_Widget *w, void *)
 		macros.text[iMacro] = macrotext->value();
 		macros.name[iMacro] = labeltext->value();
 
-		if (progdefaults.mbar2_pos) {
+		if (progdefaults.mbar_scheme > 2) {
 			if (iMacro < NUMMACKEYS) {
 				btnMacro[iMacro % NUMMACKEYS]->label( macros.name[iMacro].c_str() );
 				btnMacro[iMacro % NUMMACKEYS]->redraw_label();
@@ -390,7 +389,7 @@ Fl_Double_Window* make_macroeditor(void)
 	Fl_Tile *tile = new Fl_Tile(0,22,800,140);
 	macrotext = new Fl_Input2(0, 22, 450, 140, _("Macro Text"));
 	macrotext->type(FL_MULTILINE_INPUT);
-	macrotext->textfont(FL_COURIER);
+	macrotext->textfont(FL_HELVETICA);
 	macrotext->align(FL_ALIGN_TOP);
 
 	macroDefs = new Fl_Hold_Browser(450, 22, 350, 140, _("Select Tag"));
@@ -406,7 +405,7 @@ Fl_Double_Window* make_macroeditor(void)
 	Fl_Group *grpD = new Fl_Group(0, 164, 452, 24);
 	Fl_Box *box3a = new Fl_Box(0, 164, 327, 24, "");
 	labeltext = new Fl_Input2(337, 164, 115, 24, _("Macro Button Label"));
-	labeltext->textfont(FL_COURIER);
+	labeltext->textfont(FL_HELVETICA);
 	grpD->end();
 	grpD->resizable(box3a);
 
