@@ -95,6 +95,12 @@ modem *qpsk125_modem = 0;
 modem *qpsk250_modem = 0;
 modem *qpsk500_modem = 0;
 
+modem *_8psk125_modem = 0;
+modem *_8psk250_modem = 0;
+modem *_8psk500_modem = 0;
+modem *_8psk1000_modem = 0;
+modem *_8psk2000_modem = 0;
+
 modem *psk125r_modem = 0;
 modem *psk250r_modem = 0;
 modem *psk500r_modem = 0;
@@ -146,6 +152,7 @@ modem *olivia_64_2000_modem = 0;
 modem *contestia_modem = 0;
 
 modem *rtty_modem = 0;
+modem *pkt_modem = 0;
 
 modem *thor4_modem = 0;
 modem *thor5_modem = 0;
@@ -176,6 +183,7 @@ modem *throbx4_modem = 0;
 
 modem *wwv_modem = 0;
 modem *anal_modem = 0;
+modem *fftscan_modem = 0;
 modem *ssb_modem = 0;
 
 double modem::frequency = 1000;
@@ -289,6 +297,7 @@ void modem::set_metric(double m)
 void modem::display_metric(double m)
 {
 	set_metric(m);
+	if(!progStatus.pwrsqlonoff)
 	::global_display_metric(m);
 }
 
@@ -335,8 +344,7 @@ void modem::set_samplerate(int smprate)
 double modem::PTTnco()
 {
 	PTTphaseacc += TWOPI * 1000 / samplerate;
-	if (PTTphaseacc > M_PI)
-		PTTphaseacc -= TWOPI;
+	if (PTTphaseacc > TWOPI) PTTphaseacc -= TWOPI;
 	return sin(PTTphaseacc);
 }
 
@@ -436,7 +444,7 @@ void modem::ModulateXmtr(double *buffer, int len)
 	if (progdefaults.PTTrightchannel) {
 		for (int i = 0; i < len; i++)
 			PTTchannel[i] = PTTnco();
-			ModulateStereo( buffer, PTTchannel, len);
+			ModulateStereo( buffer, PTTchannel, len, false);
 		return;
 	}
 
@@ -471,11 +479,12 @@ void modem::ModulateXmtr(double *buffer, int len)
 
 #include <iostream>
 using namespace std;
-void modem::ModulateStereo(double *left, double *right, int len)
+void modem::ModulateStereo(double *left, double *right, int len, bool sample_flag)
 {
 	if (unlikely(!scard)) return;
 
-	tx_sample_count += len;
+	if(sample_flag)
+		tx_sample_count += len;
 
 	if (progdefaults.viewXmtSignal &&
 		!(PERFORM_CPS_TEST || active_modem->XMLRPC_CPS_TEST))
@@ -578,8 +587,7 @@ double modem::cwid_nco(double freq)
 {
 	cwid_phaseacc += 2.0 * M_PI * freq / samplerate;
 
-	if (cwid_phaseacc > M_PI)
-		cwid_phaseacc -= 2.0 * M_PI;
+	if (cwid_phaseacc > TWOPI) cwid_phaseacc -= TWOPI;
 
 	return sin(cwid_phaseacc);
 }
@@ -805,7 +813,7 @@ void modem::pretone()
 	for (int j = 0; j < symlen; j++) {
 		outbuf[j] = (0.5 * (1.0 - cos (M_PI * j / symlen)))*sin(phase);
 		phase += phaseincr;
-		if (phase > 2.0 * M_PI) phase -= 2.0 * M_PI;
+		if (phase > TWOPI) phase -= TWOPI;
 	}
 	ModulateXmtr(outbuf, symlen);
 
@@ -813,7 +821,7 @@ void modem::pretone()
 		for (int j = 0; j < symlen; j++) {
 			outbuf[j] = sin(phase);
 			phase += phaseincr;
-			if (phase > 2.0 * M_PI) phase -= 2.0 * M_PI;
+			if (phase > TWOPI) phase -= TWOPI;
 		}
 		ModulateXmtr(outbuf, symlen);
 	}
@@ -821,7 +829,7 @@ void modem::pretone()
 	for (int j = 0; j < symlen; j++) {
 		outbuf[j] = (0.5 * (1.0 - cos (M_PI * (symlen - j) / symlen)))*sin(phase);
 		phase += phaseincr;
-		if (phase > 2.0 * M_PI) phase -= 2.0 * M_PI;
+		if (phase > TWOPI) phase -= TWOPI;
 	}
 	ModulateXmtr(outbuf, symlen);
 
