@@ -6,7 +6,7 @@
 // Copyright (C) 2007-2010
 //		Stelios Bounanos, M0GLD
 //
-// This file is part of fldigi.  Adapted in part from code contained in gmfsk 
+// This file is part of fldigi.  Adapted in part from code contained in gmfsk
 // source code distribution.
 //
 // Fldigi is free software: you can redistribute it and/or modify
@@ -87,6 +87,8 @@ static  double hsbuff[SCBLOCKSIZE];
 
 static bool trxrunning = false;
 
+bool    rx_only = false;
+
 #include "tune.cxx"
 
 //=============================================================================
@@ -192,52 +194,56 @@ void trx_xmit_wfall_queue(int samplerate, const double* buf, size_t len)
 
 void trx_trx_receive_loop()
 {
-	size_t  numread;
-	int  current_samplerate;
-	assert(powerof2(SCBLOCKSIZE));
+    size_t  numread;
+    int  current_samplerate;
+    assert(powerof2(SCBLOCKSIZE));
 
-	if (unlikely(!active_modem)) {
-		MilliSleep(10);
-		return;
-	}
+    if (unlikely(!active_modem)) {
+	MilliSleep(10);
+	return;
+    }
 
 #if BENCHMARK_MODE
-	do_benchmark();
-	trx_state = STATE_ENDED;
-	return;
+    do_benchmark();
+    trx_state = STATE_ENDED;
+    return;
 #endif
 
-	if (unlikely(!scard)) {
-		MilliSleep(10);
-		return;
-	}
+    if (unlikely(!scard)) {
+	MilliSleep(10);
+	return;
+    }
 
-	try {
-		current_samplerate = active_modem->get_samplerate();
-		if (scard->Open(O_RDONLY, current_samplerate))
-			REQ(sound_update, progdefaults.btnAudioIOis);
+    try {
+	current_samplerate = active_modem->get_samplerate();
+	if (scard->Open(O_RDONLY, current_samplerate))
+	    REQ(sound_update, progdefaults.btnAudioIOis);
+    }
+    catch (const SndException& e) {
+	LOG_ERROR("%s. line: %i", e.what(), __LINE__);
+	put_status(e.what(), 5);
+	scard->Close();
+	if (e.error() == EBUSY && progdefaults.btnAudioIOis == SND_IDX_PORT) {
+	    sound_close();
+	    sound_init();
 	}
-	catch (const SndException& e) {
-		LOG_ERROR("%s", e.what());
-		put_status(e.what(), 5);
-		scard->Close();
-		if (e.error() == EBUSY && progdefaults.btnAudioIOis == SND_IDX_PORT) {
-			sound_close();
-			sound_init();
-		}
-		MilliSleep(1000);
-		return;
-	}
-	active_modem->rx_init();
+	MilliSleep(1000);
+	return;
+    }
+    active_modem->rx_init();
 
-	ringbuffer<double>::vector_type rbvec[2];
-	rbvec[0].buf = rbvec[1].buf = 0;
+    ringbuffer<double>::vector_type rbvec[2];
+    rbvec[0].buf = rbvec[1].buf = 0;
 
 	while (1) {
 		try {
 			numread = 0;
 			while (numread < SCBLOCKSIZE && trx_state == STATE_RX)
 				numread += scard->Read(fbuf + numread, SCBLOCKSIZE - numread);
+			if (numread > SCBLOCKSIZE) {
+				LOG_ERROR("numread error %lu", (unsigned long) numread);
+				numread = SCBLOCKSIZE;
+			}
 			if (bHighSpeed) {
 				for (size_t i = 0; i < numread; i++)
 					hsbuff[i] = fbuf[i];
@@ -252,7 +258,7 @@ void trx_trx_receive_loop()
 		}
 		catch (const SndException& e) {
 			scard->Close();
-			LOG_ERROR("%s", e.what());
+			LOG_ERROR("%s. line: %i", e.what(), __LINE__);
 			put_status(e.what(), 5);
 			MilliSleep(10);
 			return;
@@ -305,6 +311,8 @@ void trx_trx_receive_loop()
 //=============================================================================
 void trx_trx_transmit_loop()
 {
+	if (rx_only) return;
+
 	int  current_samplerate;
 	if (!scard) {
 		MilliSleep(10);
@@ -313,17 +321,17 @@ void trx_trx_transmit_loop()
 	if (active_modem) {
 
 		try {
-			current_samplerate = active_modem->get_samplerate();
-			scard->Open(O_WRONLY, current_samplerate);
+		    current_samplerate = active_modem->get_samplerate();
+		    scard->Open(O_WRONLY, current_samplerate);
 		}
 		catch (const SndException& e) {
-			LOG_ERROR("%s", e.what());
-			put_status(e.what(), 1);
-			MilliSleep(10);
-			return;
+		    LOG_ERROR("%s. line: %i", e.what(), __LINE__);
+		    put_status(e.what(), 1);
+		    MilliSleep(10);
+		    return;
 		}
 
-		if ((active_modem != ssb_modem) && 
+		if ((active_modem != ssb_modem) &&
 			(active_modem != anal_modem) &&
 			!active_modem->XMLRPC_CPS_TEST &&
 			!PERFORM_CPS_TEST ) {
@@ -334,7 +342,7 @@ void trx_trx_transmit_loop()
 
 		if (!progdefaults.DTMFstr.empty()) dtmf->send();
 
-		if ( ReedSolomon->assigned(active_modem->get_mode()) && 
+		if ( ReedSolomon->assigned(active_modem->get_mode()) &&
 			 (progdefaults.TransmitRSid || progStatus.n_rsids != 0)) {
 			if (progStatus.n_rsids < 0) {
 				for (int i = 0; i > progStatus.n_rsids; i--) {
@@ -376,7 +384,7 @@ void trx_trx_transmit_loop()
 		} else
 			trx_state = STATE_RX;
 
-		if (ReedSolomon->assigned(active_modem->get_mode()) && 
+		if (ReedSolomon->assigned(active_modem->get_mode()) &&
 			progdefaults.TransmitRSid &&
 			progdefaults.rsid_post &&
 			progStatus.n_rsids >= 0) ReedSolomon->send(false);
@@ -402,6 +410,8 @@ void trx_trx_transmit_loop()
 //=============================================================================
 void trx_tune_loop()
 {
+	if (rx_only) return;
+
 	int  current_samplerate;
 	if (!scard) {
 		MilliSleep(10);
@@ -409,14 +419,14 @@ void trx_tune_loop()
 	}
 	if (active_modem) {
 		try {
-			current_samplerate = active_modem->get_samplerate();
-			scard->Open(O_WRONLY, current_samplerate);
+		    current_samplerate = active_modem->get_samplerate();
+		    scard->Open(O_WRONLY, current_samplerate);
 		}
 		catch (const SndException& e) {
-			LOG_ERROR("%s", e.what());
-			put_status(e.what(), 1);
-			MilliSleep(10);
-			return;
+		    LOG_ERROR("%s. line: %i", e.what(), __LINE__);
+		    put_status(e.what(), 1);
+		    MilliSleep(10);
+		    return;
 		}
 
 		push2talk->set(true);
@@ -435,7 +445,7 @@ void trx_tune_loop()
 		}
 		catch (const SndException& e) {
 			scard->Close();
-			LOG_ERROR("%s", e.what());
+			LOG_ERROR("%s. line: %i", e.what(), __LINE__);
 			put_status(e.what(), 5);
 			MilliSleep(10);
 			return;
@@ -575,7 +585,7 @@ void trx_reset_loop()
 		abort();
 	}
 
-	trx_state = STATE_RX;	
+	trx_state = STATE_RX;
 }
 
 //=============================================================================
@@ -594,7 +604,7 @@ void trx_start(void)
 		LOG(debug::ERROR_LEVEL, debug::LOG_MODEM, "trx already running!");
 		return;
 	}
-	
+
 	if (scard) delete scard;
 	if (ReedSolomon) delete ReedSolomon;
 	if (dtmf) delete dtmf;
@@ -656,7 +666,7 @@ void trx_start(void)
 		LOG(debug::ERROR_LEVEL, debug::LOG_MODEM, "pthread_create failed");
 		trxrunning = false;
 		exit(1);
-	} 
+	}
 	trxrunning = true;
 }
 
