@@ -52,7 +52,8 @@ Digiscope::Digiscope (int X, int Y, int W, int H) :
 	_highlight = false;
 	_len = MAX_LEN;
 	_zptr = 0;
-	_x1 = _x2 = _y1 = _y2;
+	for (int i = 0; i < NUM_GRIDS; i++)
+		_x[i] = _y[i] = 0;
 	phase_mode = PHASE1;
 }
 
@@ -139,9 +140,11 @@ void Digiscope::data(double *data, int len, bool scale)
 			max = MAX(max, _buf[i]);
 			min = MIN(min, _buf[i]);
 		}
-		if (max == min) max *= 1.001;
 		for (int i = 0; i < _len; i++)
-			_buf[i] = (_buf[i] - min) / (max - min);
+			if (_buf[i] > 0.001) // threshold
+				_buf[i] = (_buf[i] - min) / (max - min);
+			else
+				_buf[i] = 0.0;
 	}
 	REQ_DROP(&Digiscope::redraw, this);
 	FL_UNLOCK_D();
@@ -293,33 +296,21 @@ void Digiscope::draw_scope()
 	fl_end_line();
 
 // x & y axis'
-	if (_x1) {
-		fl_color(FL_WHITE);
-		fl_begin_line();
-			fl_vertex(_x1, 0.0);
-			fl_vertex(_x1, 1.0);
-		fl_end_line();
-	}
-	if (_x2) {
-		fl_color(FL_YELLOW);
-		fl_begin_line();
-			fl_vertex(_x2, 0.0);
-			fl_vertex(_x2, 1.0);
-		fl_end_line();
-	}
-	if (_y1) {
-		fl_color(FL_WHITE);
-		fl_begin_line();
-			fl_vertex(0.0, _y1);
-			fl_vertex(1.0, _y1);
-		fl_end_line();
-	}
-	if (_y2) {
-		fl_color(FL_YELLOW);
-		fl_begin_line();
-			fl_vertex(0.0, _y2);
-			fl_vertex(1.0, _y2);
-		fl_end_line();
+	for (int i = 0; i < NUM_GRIDS; i++) {
+		if (_x[i]) {
+			fl_color(FL_WHITE);
+			fl_begin_line();
+			fl_vertex(_x[i], 0.0);
+			fl_vertex(_x[i], 1.0);
+			fl_end_line();
+		}
+		if (_y[i]) {
+			fl_color(FL_WHITE);
+			fl_begin_line();
+			fl_vertex(0.0, _y[i]);
+			fl_vertex(1.0, _y[i]);
+			fl_end_line();
+		}
 	}
 
 	fl_pop_matrix();
@@ -508,5 +499,4 @@ void Digiscope::resize(int x, int y, int w, int h)
 	vidline = new unsigned char[ 3 * (w-4)];
 
 	Fl_Widget::resize(x, y, w, h);
-	mode(_mode);
 }
