@@ -51,6 +51,7 @@
 #include "main.h"
 #include "modem.h"
 #include "qrunner.h"
+#include "threads.h"
 
 #if USE_HAMLIB
 	#include "hamlib.h"
@@ -111,6 +112,8 @@ RGB		palette[9];
 
 short int *tmp_fft_db;
 
+static pthread_mutex_t waterfall_mutex = PTHREAD_MUTEX_INITIALIZER;
+
 WFdisp::WFdisp (int x0, int y0, int w0, int h0, char *lbl) :
 			  Fl_Widget(x0,y0,w0,h0,"") {
 	disp_width = w();
@@ -118,7 +121,7 @@ WFdisp::WFdisp (int x0, int y0, int w0, int h0, char *lbl) :
 		disp_width = progdefaults.HighFreqCutoff/4;
 	scale_width = IMAGE_WIDTH * 2;
 	image_height = h() - WFTEXT - WFSCALE - WFMARKER;
-	image_area	  = IMAGE_WIDTH * image_height;
+	image_area      = IMAGE_WIDTH * image_height;
 	sig_image_area  = IMAGE_WIDTH * h();
 	RGBsize			= sizeof(RGB);
 	RGBwidth		= RGBsize * scale_width;
@@ -162,7 +165,8 @@ WFdisp::WFdisp (int x0, int y0, int w0, int h0, char *lbl) :
 	wfspeed = NORMAL;
 	srate = 8000;
 	wfspdcnt = 0;
-	dispcnt = 4;
+	dispcnt = 1.0 * WFBLOCKSIZE / SC_SMPLRATE;
+	dispdec = 1.0 * WFBLOCKSIZE / srate;
 	wantcursor = false;
 	cursormoved = false;
 //	usebands = false;
@@ -208,8 +212,10 @@ inline void WFdisp::makeMarker_(int width, const RGB* color, int freq, const RGB
 	if (marker_mode == MODE_RTTY) {
 	// rtty has two bandwidth indicators on the waterfall
 	// upper and lower frequency
-		int shift = static_cast<int>(progdefaults.rtty_shift >= 0 ?
-				 rtty::SHIFT[progdefaults.rtty_shift] : progdefaults.rtty_custom_shift);
+		int shift = static_cast<int>(
+			(progdefaults.rtty_shift < rtty::numshifts ?
+				rtty::SHIFT[progdefaults.rtty_shift] :
+				progdefaults.rtty_custom_shift));
 		int bw_limit_hi = (int)(shift / 2 + progdefaults.RTTY_BW / 2.0);
 		int bw_limit_lo = (int)(shift / 2 - progdefaults.RTTY_BW / 2.0);
 		int bw_freq = static_cast<int>(freq + 0.5);
@@ -217,7 +223,7 @@ inline void WFdisp::makeMarker_(int width, const RGB* color, int freq, const RGB
 		int bw_upper1 = -bw_limit_lo;
 		int bw_lower2 = bw_limit_lo;
 		int bw_upper2 = bw_limit_hi;
-		if (bw_lower1 + bw_freq < 0) 
+		if (bw_lower1 + bw_freq < 0)
 			bw_lower1 -= bw_lower1 + bw_freq;
 		if (bw_upper1 + bw_freq < 0)
 			bw_lower2 -= bw_lower2 + bw_freq;
@@ -283,7 +289,9 @@ void WFdisp::makeMarker()
 	else if (mode >= MODE_FELDHELL && mode <= MODE_HELL80)
 		marker_width = (int)progdefaults.HELL_BW;
 	else if (mode == MODE_RTTY)
-		marker_width = static_cast<int>(rtty::SHIFT[progdefaults.rtty_shift]);
+		marker_width = static_cast<int>((progdefaults.rtty_shift < rtty::numshifts ?
+				  rtty::SHIFT[progdefaults.rtty_shift] :
+				  progdefaults.rtty_custom_shift));
 	marker_width = (int)(marker_width / 2.0 + 1);
 
 	RGBmarker.R = progdefaults.bwTrackRGBI.R;
@@ -407,6 +415,8 @@ void WFdisp::initmaps() {
 
 int WFdisp::peakFreq(int f0, int delta)
 {
+	guard_lock waterfall_lock(&waterfall_mutex);
+
 	double threshold = 0.0;
 	int f1, fmin =	(int)((f0 - delta)),
 		f2, fmax =	(int)((f0 + delta));
@@ -428,6 +438,8 @@ int WFdisp::peakFreq(int f0, int delta)
 
 double WFdisp::powerDensity(double f0, double bw)
 {
+	guard_lock waterfall_lock(&waterfall_mutex);
+
 	double pwrdensity = 0.0;
 	int flower = (int)((f0 - bw/2)),
 		fupper = (int)((f0 + bw/2));
@@ -438,9 +450,11 @@ double WFdisp::powerDensity(double f0, double bw)
 	return pwrdensity/(bw+1);
 }
 
-// Frequency of the maximum power for a given bandwidth. Used for AFC.
+/// Frequency of the maximum power for a given bandwidth. Used for AFC.
 double WFdisp::powerDensityMaximum(int bw_nb, const int (*bw)[2]) const
 {
+	guard_lock waterfall_lock(&waterfall_mutex);
+
 	double max_pwr = 0 ;
 	int f_lowest = bw[0][0];
 	int f_highest = bw[bw_nb-1][1];
@@ -458,10 +472,10 @@ double WFdisp::powerDensityMaximum(int bw_nb, const int (*bw)[2]) const
 
 	double curr_pwr = max_pwr ;
 	int max_idx = -1 ;
-	// Single pass to compute the maximum on this bandwidth.
+	/// Single pass to compute the maximum on this bandwidth.
 	for( int f = -f_lowest ; f < IMAGE_WIDTH - f_highest; ++f )
 	{
-		// Difference with previous power.
+		/// Difference with previous power.
 		for( int i = 0 ; i < bw_nb; ++i )
 		{
 			const int * p_bw = bw[i];
@@ -501,7 +515,7 @@ void WFdisp::processFFT() {
 
 	wf_fft_type scale = ( 1.0 * SC_SMPLRATE / srate ) * ( FFT_LEN / 8000.0);
 
-	if (--dispcnt == 0) {
+	if ((dispcnt -= dispdec) <= 0) {
 		static const int log2disp100 = log2disp(-100);
 		double vscale = 2.0 / FFT_LEN;
 
@@ -543,14 +557,12 @@ void WFdisp::processFFT() {
 		}
 		redraw();
 
-		if (srate == 8000)
-			dispcnt = wfspeed;
-		else if (srate == 11025)
-			dispcnt = wfspeed * 4 / 3;
-		//kl4yfd
-		else
-			dispcnt = wfspeed * 8 / 3;
+		dispcnt = 1.0 * WFBLOCKSIZE / SC_SMPLRATE; // FAST
+		if (wfspeed == NORMAL) dispcnt *= NORMAL;
+		if (wfspeed == SLOW) dispcnt *= progdefaults.drop_speed;
 	}
+	dispdec = 1.0 * WFBLOCKSIZE / srate;
+	if (wfspeed == PAUSE) dispdec = 0;
 }
 
 void WFdisp::process_analog (wf_fft_type *sig, int len) {
@@ -603,9 +615,9 @@ void WFdisp::sig_data( double *sig, int len, int sr )
 	}
 
 	memmove((void*)circbuff,
-			(void*)(circbuff + len), 
+			(void*)(circbuff + len),
 			(size_t)((FFT_LEN - len)*sizeof(wf_fft_type)));
-	memcpy((void*)&circbuff[FFT_LEN-len], 
+	memcpy((void*)&circbuff[FFT_LEN-len],
 			(void*)sig,
 			(size_t)(len)*sizeof(double));
 
@@ -633,8 +645,9 @@ update_freq:
 		int rttyoffset = 0;
 		trx_mode mode = active_modem->get_mode();
 		if (mode == MODE_RTTY && progdefaults.useMARKfreq) {
-			rttyoffset = (progdefaults.rtty_shift >= 0 ?
-				rtty::SHIFT[progdefaults.rtty_shift] : progdefaults.rtty_custom_shift);
+			rttyoffset = (progdefaults.rtty_shift < rtty::numshifts ?
+				  rtty::SHIFT[progdefaults.rtty_shift] :
+				  progdefaults.rtty_custom_shift);
 			rttyoffset /= 2;
 			if (active_modem->get_reverse()) rttyoffset *= -1;
 		}
@@ -643,10 +656,14 @@ update_freq:
 			cwoffset = progdefaults.CWsweetspot;
 			usb = ! (progdefaults.CWIsLSB ^ (testmode == "CWR"));
 		}
-		if (usb)
-			dfreq = rfc + active_modem->get_txfreq() - cwoffset + rttyoffset;
-		else
-			dfreq = rfc - active_modem->get_txfreq() + cwoffset - rttyoffset;
+		if (mode == MODE_ANALYSIS) {
+			dfreq = active_modem->track_freq();
+		} else {
+			if (usb)
+				dfreq = rfc + active_modem->get_txfreq() - cwoffset + rttyoffset;
+			else
+				dfreq = rfc - active_modem->get_txfreq() + cwoffset - rttyoffset;
+		}
 		snprintf(szFrequency, sizeof(szFrequency), "%-.3f", dfreq / 1000.0);
 	} else {
 		dfreq = active_modem->get_txfreq();
@@ -777,12 +794,12 @@ void WFdisp::drawScale() {
 		if (progdefaults.wf_audioscale)
 			fr = 500.0 * i;
 		else {
-			int cwoffset = 0;
-			string testmode = qso_opMODE->value();
-			if (testmode == "CW" or testmode == "CWR") {
+		    int cwoffset = 0;
+		    string testmode = qso_opMODE->value();
+		    if (testmode == "CW" or testmode == "CWR") {
 				cwoffset = ( progdefaults.CWOffset ? progdefaults.CWsweetspot : 0 );
-				usb = ! (progdefaults.CWIsLSB ^ (testmode == "CWR")); 
-			}
+				usb = ! (progdefaults.CWIsLSB ^ (testmode == "CWR"));
+		    }
 			if (usb)
 				fr = (rfc - (rfc%500))/1000.0 + 0.5*i - cwoffset/1000.0;
 			else
@@ -921,7 +938,7 @@ void WFdisp::drawcolorWF() {
 
 	update_waterfall();
 
-	if (active_modem && wantcursor && 
+	if (active_modem && wantcursor &&
 		(progdefaults.UseCursorLines || progdefaults.UseCursorCenterLine) ) {
 		trx_mode mode = active_modem->get_mode();
 		int bw_lo = bandwidth / 2;
@@ -989,7 +1006,7 @@ void WFdisp::drawspectrum() {
 	if (progdefaults.UseBWTracks) {
 		uchar  *pos1 = pixmap + (carrierfreq - offset - bandwidth/2) / step;
 		uchar  *pos2 = pixmap + (carrierfreq - offset + bandwidth/2) / step;
-		if (pos1 >= pixmap && 
+		if (pos1 >= pixmap &&
 			pos2 < pixmap + disp_width)
 			for (int y = 0; y < image_height; y ++) {
 				*pos1 = *pos2 = 255;
@@ -1001,7 +1018,7 @@ void WFdisp::drawspectrum() {
 				pos2 += IMAGE_WIDTH/step;
 			}
 	}
-	if (active_modem && wantcursor && 
+	if (active_modem && wantcursor &&
 		(progdefaults.UseCursorLines || progdefaults.UseCursorCenterLine)) {
 		trx_mode mode = active_modem->get_mode();
 		int bw_lo = bandwidth / 2;
@@ -1290,7 +1307,7 @@ void ampspan_cb(Fl_Widget *w, void *v) {
 	restoreFocus();
 }
 
-void btnRev_cb(Fl_Widget *w, void *v) 
+void btnRev_cb(Fl_Widget *w, void *v)
 {
 	if (!active_modem) return;
 	FL_LOCK_D();
@@ -1404,7 +1421,7 @@ void waterfall::opmode() {
 	int val = (int)active_modem->get_bandwidth();
 
 	wfdisp->carrier((int)CLAMP(
-		wfdisp->carrier(), 
+		wfdisp->carrier(),
 		progdefaults.LowFreqCutoff + val / 2,
 		progdefaults.HighFreqCutoff - val / 2));
 
@@ -1532,6 +1549,7 @@ void waterfall::show_scope(bool on)
 		wfdisp->size( wf->w() - 2 * BEZEL, wf_dim - 2 * BEZEL);
 		rs1->init_sizes();
 	}
+	wfscope->redraw();
 }
 
 waterfall::waterfall(int x0, int y0, int w0, int h0, char *lbl) :
@@ -1743,7 +1761,7 @@ int waterfall::handle(int event)
 		for (;;) {
 			mode = WCLAMP(mode + d, 0, NUM_MODES - 1);
 			if ((mode >= NUM_RXTX_MODES && mode < NUM_MODES) ||
-				progdefaults.visible_modes.test(mode))
+			    progdefaults.visible_modes.test(mode))
 				break;
 		}
 		init_modem(mode);
@@ -1752,7 +1770,7 @@ int waterfall::handle(int event)
 	// as above; handle wheel events for the macro bar
 	extern void altmacro_cb(Fl_Widget *w, void *v);
 	if (progdefaults.macro_wheel) {
-		if (progdefaults.mbar2_pos) {
+		if (progdefaults.mbar_scheme > 2) {
 			if (Fl::event_inside(macroFrame2)) {
 				altmacro_cb(btnAltMacros2, reinterpret_cast<void *>(d));
 				return 1;
@@ -1785,7 +1803,7 @@ void waterfall::insert_text(bool check)
 		m.mode = active_modem->get_mode();
 		extern qrg_mode_t last_marked_qrg;
 		if (last_marked_qrg.mode == m.mode && last_marked_qrg.rfcarrier == m.rfcarrier &&
-			abs(last_marked_qrg.carrier - m.carrier) <= 16)
+		    abs(last_marked_qrg.carrier - m.carrier) <= 16)
 			return;
 		last_marked_qrg = m;
 	}
@@ -1819,7 +1837,7 @@ static void find_signal_text(void)
 		// try the other direction
 		int pos = ReceiveText->insert_position();
 		if (ReceiveText->buffer()->search_backward(pos, i->first.c_str(), &pos, 1) ||
-			ReceiveText->buffer()->search_forward(pos, i->first.c_str(), &pos, 1)) {
+		    ReceiveText->buffer()->search_forward(pos, i->first.c_str(), &pos, 1)) {
 			ReceiveText->insert_position(pos);
 			ReceiveText->show_insert_position();
 		}
@@ -1905,8 +1923,8 @@ int WFdisp::handle(int event)
 				if (!progdefaults.WaterfallHistoryDefault)
 					bHistory = true;
 				if (eb == FL_LEFT_MOUSE) {
-					   restoreFocus();
-					   break;
+				       restoreFocus();
+				       break;
 				}
 			}
 			if (progdefaults.WaterfallHistoryDefault)
@@ -1914,8 +1932,8 @@ int WFdisp::handle(int event)
 			newcarrier = cursorFreq(xpos);
 			if (active_modem) {
 				newcarrier = (int)CLAMP(
-					newcarrier, 
-					progdefaults.LowFreqCutoff + active_modem->get_bandwidth() / 2, 
+					newcarrier,
+					progdefaults.LowFreqCutoff + active_modem->get_bandwidth() / 2,
 					progdefaults.HighFreqCutoff - active_modem->get_bandwidth() / 2);
 				active_modem->set_freq(newcarrier);
 				viewer_paste_freq(newcarrier);
@@ -2000,8 +2018,8 @@ int WFdisp::handle(int event)
 				d = -d;
 			if (active_modem) {
 				oldcarrier = newcarrier = (int)CLAMP(
-					carrier() + d, 
-					progdefaults.LowFreqCutoff + active_modem->get_bandwidth() / 2, 
+					carrier() + d,
+					progdefaults.LowFreqCutoff + active_modem->get_bandwidth() / 2,
 					progdefaults.HighFreqCutoff - active_modem->get_bandwidth() / 2);
 				active_modem->set_freq(newcarrier);
 			}
@@ -2021,8 +2039,8 @@ int WFdisp::handle(int event)
 		if (Fl::event_inside(this)) {
 			int k = Fl::event_key();
 			if (k == FL_Shift_L || k == FL_Shift_R || k == FL_Control_L ||
-				k == FL_Control_R || k == FL_Meta_L || k == FL_Meta_R ||
-				k == FL_Alt_L || k == FL_Alt_R)
+			    k == FL_Control_R || k == FL_Meta_L || k == FL_Meta_R ||
+			    k == FL_Alt_L || k == FL_Alt_R)
 				restoreFocus();
 		}
 		break;
@@ -2086,7 +2104,7 @@ void waterfall::handle_mouse_wheel(int what, int d)
 		val = sldrSquelch;
 		d = -d;
 		msg_fmt = "%s = %2.0f %%";
-		msg_label = "Sqlch";
+		msg_label = "Squelch";
 		break;
 	case WF_CARRIER:
 		val = wfcarrier;
