@@ -98,8 +98,6 @@ private:
 	bool draw_marks;
 };
 
-static void show_font_warning(FTextBase* w);
-
 Fl_Menu_Item FTextRX::menu[] = {
 	{ make_icon_label(_("Look up call"), net_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
 	{ make_icon_label(_("Call"), enter_key_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
@@ -173,20 +171,29 @@ int FTextRX::handle(int event)
 	static Fl_Cursor cursor;
 
 	switch (event) {
+	case FL_DRAG:
+		if (Fl::event_button() != FL_LEFT_MOUSE)
+			return 1;
+		break;
 	case FL_PUSH:
 		if (!Fl::event_inside(this))
 			break;
- 		switch (Fl::event_button()) {
+		switch (Fl::event_button()) {
 		case FL_LEFT_MOUSE:
-			if (Fl::event_shift() || (unlikely(Fl::event_clicks()) && progdefaults.rxtext_clicks_qso_data)) {
-				handle_qso_data(Fl::event_x() - x(), Fl::event_y() - y());
-				return 1;
+			if (Fl::event_shift() || progdefaults.rxtext_clicks_qso_data) {
+				if (handle_clickable(Fl::event_x() - x(), Fl::event_y() - y()))
+					return 1;
+				if (handle_qso_data(Fl::event_x() - x(), Fl::event_y() - y()))
+					return 1;
 			}
 			goto out;
 		case FL_MIDDLE_MOUSE:
-			if (cursor != FL_CURSOR_HAND)
-				handle_qso_data(Fl::event_x() - x(), Fl::event_y() - y());
-			return 1;
+			if (cursor != FL_CURSOR_HAND) {
+				if (handle_qso_data(Fl::event_x() - x(), Fl::event_y() - y())) {
+					return 1;
+				}
+			}
+			goto out;
  		case FL_RIGHT_MOUSE:
 			handle_context_menu();
 			return 1;
@@ -194,19 +201,8 @@ int FTextRX::handle(int event)
  			goto out;
  		}
 		break;
-	case FL_DRAG:
-		if (Fl::event_button() != FL_LEFT_MOUSE)
-			return 1;
-		break;
 	case FL_RELEASE:
-		{	int eb = Fl::event_button();
-			if (cursor == FL_CURSOR_HAND && eb == FL_LEFT_MOUSE &&
-			    Fl::event_is_click() && !Fl::event_clicks()) {
-				handle_clickable(Fl::event_x() - x(), Fl::event_y() - y());
-				return 1;
-			}
 			break;
-		}
 	case FL_MOVE: {
 		int p = xy_to_position(Fl::event_x(), Fl::event_y(), Fl_Text_Display_mod::CURSOR_POS);
 		if ((unsigned char)sbuf->byte_at(p) >= CLICK_START + FTEXT_DEF) {
@@ -381,10 +377,9 @@ void FTextRX::clear(void)
 void FTextRX::setFont(Fl_Font f, int attr)
 {
 	FTextBase::setFont(f, attr);
-	show_font_warning(this);
 }
 
-void FTextRX::handle_clickable(int x, int y)
+int FTextRX::handle_clickable(int x, int y)
 {
 	int pos;
 	unsigned int style;
@@ -392,7 +387,7 @@ void FTextRX::handle_clickable(int x, int y)
 	pos = xy_to_position(x + this->x(), y + this->y(), CURSOR_POS);
 	// return unless clickable style
 	if ((style = (unsigned char)sbuf->byte_at(pos)) < CLICK_START + FTEXT_DEF)
-		return;
+		return 0;
 
 	int start, end;
 	for (start = pos-1; start >= 0; start--)
@@ -412,6 +407,7 @@ void FTextRX::handle_clickable(int x, int y)
 	default:
 		break;
 	}
+	return 0;
 }
 
 void FTextRX::handle_qsy(int start, int end)
@@ -434,11 +430,11 @@ static fre_t rst("^[1-5][1-9]{2}$", REG_EXTENDED | REG_NOSUB);
 static fre_t loc("[a-r]{2}[[:digit:]]{2}([a-x]{2})?", REG_EXTENDED | REG_ICASE);
 static fre_t call("([[:alnum:]]?[[:alpha:]/]+[[:digit:]]+[[:alnum:]/]+)", REG_EXTENDED);
 
-void FTextRX::handle_qso_data(int start, int end)
+int FTextRX::handle_qso_data(int start, int end)
 {
 	char* s = get_word(start, end, progdefaults.nonwordchars.c_str());
 	if (!s)
-		return;
+		return 0;
 	char* p = s;
 
 	Fl_Input* target = 0;
@@ -470,13 +466,17 @@ void FTextRX::handle_qso_data(int start, int end)
 			target = inpQth;
 		else
 			target = *inpName->value() ? inpQth : inpName;
-
-		target->value(p);
-		target->do_callback();
+		if (target) {
+			target->value(p);
+			target->do_callback();
+			free(s);
+			restoreFocus(NULL);
+			return 1;
+		}
 	}
 	free(s);
-
-	restoreFocus(NULL);
+	return 0;
+//	restoreFocus(NULL);
 }
 
 void FTextRX::handle_context_menu(void)
@@ -904,7 +904,6 @@ void FTextTX::add_text(string s)
 void FTextTX::setFont(Fl_Font f, int attr)
 {
 	FTextBase::setFont(f, attr);
-	show_font_warning(this);
 }
 
 /// Handles keyboard shorcuts
@@ -1105,7 +1104,7 @@ int FTextTX::handle_key(int key)
 		if (Fl::event_state() & FL_ALT) {
 			static char lbl[2] = "1";
 			altMacros = key - '1';
-			if (progdefaults.mbar2_pos) {
+			if (progdefaults.mbar_scheme > 2) {
 				if (!altMacros) altMacros = 1;
 				for (int i = 0; i < NUMMACKEYS; i++) {
 					btnMacro[NUMMACKEYS + i]->label(
@@ -1163,7 +1162,7 @@ int FTextTX::handle_key_macro(int key)
 	if (key > 11)
 		return 0;
 
-	if (progdefaults.mbar2_pos) {
+	if (progdefaults.mbar_scheme > 2) {
 		if (Fl::event_state(FL_SHIFT))
 			key += altMacros * NUMMACKEYS;
 	} else {
@@ -1357,36 +1356,6 @@ int FTextTX::kf_paste(int c, Fl_Text_Editor_mod* e)
 	return e->insert_position() < *ptxpos ? 1 : Fl_Text_Editor_mod::kf_paste(c, e);
 }
 
-static void show_font_warning(FTextBase* w)
-{
-	Fl_Font f = w->textfont();
-
-	if (Font_Browser::fixed_width(f))
-		return;
-
-	// Check if we should generate a warning message
-	bool* warn = 0;
-	const char* fn = Fl::get_font_name(f);
-	if (w == ReceiveText) {
-		warn = &progdefaults.RxFontWarn;
-		if (progdefaults.RxFontName != fn)
-			*warn = true;
-	}
-	else if (w == TransmitText) {
-		warn = &progdefaults.TxFontWarn;
-		if (progdefaults.TxFontName != fn)
-			*warn = true;
-	}
-	if (warn && *warn) {
-		w->add(Fl::get_font_name(f), FTextBase::XMIT);
-		w->add(" is a variable width font.\n", FTextBase::XMIT);
-		w->add("Line wrapping with a variable width font may be\n"
-		       "too slow. Consider using a fixed width font.\n\n", FTextBase::XMIT);
-		*warn = false;
-	}
-}
-
-
 // ----------------------------------------------------------------------------
 
 
