@@ -67,7 +67,7 @@ FTextBase::FTextBase(int x, int y, int w, int h, const char *l)
 {
 	oldw = oldh = olds = -1;
 	oldf = (Fl_Font)-1;
-	textfont(FL_COURIER);
+	textfont(FL_HELVETICA);
 	textsize(FL_NORMAL_SIZE);
 	textcolor(FL_FOREGROUND_COLOR);
 
@@ -466,11 +466,11 @@ int FTextBase::reset_wrap_col(void)
 
 void FTextBase::reset_styles(int set)
 {
-	set_style(NATTR, FL_COURIER, FL_NORMAL_SIZE, FL_FOREGROUND_COLOR, set);
-	set_style(XMIT, FL_COURIER, FL_NORMAL_SIZE, FL_RED, set);
-	set_style(CTRL, FL_COURIER, FL_NORMAL_SIZE, FL_DARK_GREEN, set);
-	set_style(SKIP, FL_COURIER, FL_NORMAL_SIZE, FL_BLUE, set);
-	set_style(ALTR, FL_COURIER, FL_NORMAL_SIZE, FL_DARK_MAGENTA, set);
+	set_style(NATTR, FL_HELVETICA, FL_NORMAL_SIZE, FL_FOREGROUND_COLOR, set);
+	set_style(XMIT, FL_HELVETICA, FL_NORMAL_SIZE, FL_RED, set);
+	set_style(CTRL, FL_HELVETICA, FL_NORMAL_SIZE, FL_DARK_GREEN, set);
+	set_style(SKIP, FL_HELVETICA, FL_NORMAL_SIZE, FL_BLUE, set);
+	set_style(ALTR, FL_HELVETICA, FL_NORMAL_SIZE, FL_DARK_MAGENTA, set);
 }
 
 // ----------------------------------------------------------------------------
@@ -719,15 +719,11 @@ int FTextEdit::handle_key(int key)
 {
 // read ctl-ddd, where d is a digit, as ascii characters (in base 10)
 // and insert verbatim; e.g. ctl-001 inserts a <soh>
-	if (key == FL_Control_L || key == FL_Control_R) return 0;
-	bool t1 = isdigit(key);
-	bool t2 = false;
-	if (key >= FL_KP) t2 = isdigit(key - FL_KP + '0');
-	bool t3 = (Fl::event_state() & FL_CTRL) == FL_CTRL;
-	if (t3 && (t1 || t2))
+	if (Fl::event_state() & FL_CTRL && (isdigit(key) || isdigit(key - FL_KP)))
 		return handle_key_ascii(key);
 	ascii_cnt = 0; // restart the numeric keypad entries.
 	ascii_chr = 0;
+
 	return 0;
 }
 
