@@ -38,6 +38,8 @@
 
 typedef int socklen_t;
 
+#include "compat.h"
+
 #else
 extern "C" {
 # include <unistd.h>
@@ -53,13 +55,9 @@ extern "C" {
 }
 #endif  // _WINDOWS
 
-
 using namespace XmlRpc;
-
-
 // One-time initializations
 static bool initialized = false;
-  
 
 static void initialize()
 {
@@ -67,9 +65,10 @@ static void initialize()
 
 #if defined(_WINDOWS)
     {
-        WORD wVersionRequested = MAKEWORD( 2, 0 );
+        WORD wVersionRequested = MAKEWORD( WSA_MAJOR, WSA_MINOR );
         WSADATA wsaData;
         WSAStartup(wVersionRequested, &wsaData);
+       	atexit((void(*)(void)) WSACleanup);
     }
 #else
     {
@@ -79,8 +78,6 @@ static void initialize()
 #endif // _WINDOWS
 }
 
-
-
 // These errors are not considered fatal for an IO operation; the operation will be re-tried.
 bool
 XmlRpcSocket::nonFatalError()
@@ -104,7 +101,6 @@ XmlRpcSocket::socket()
   return ::socket(AF_INET, SOCK_STREAM, 0);
 }
 
-
 void
 XmlRpcSocket::close(XmlRpcSocket::Socket fd)
 {
@@ -141,7 +137,7 @@ XmlRpcSocket::setReuseAddr(XmlRpcSocket::Socket fd)
 
 
 // Bind to a specified port
-bool 
+bool
 XmlRpcSocket::bind(XmlRpcSocket::Socket fd, int port)
 {
   struct sockaddr_in saddr;
@@ -154,7 +150,7 @@ XmlRpcSocket::bind(XmlRpcSocket::Socket fd, int port)
 
 
 // Set socket in listen mode
-bool 
+bool
 XmlRpcSocket::listen(XmlRpcSocket::Socket fd, int backlog)
 {
   return (::listen(fd, backlog) == 0);
@@ -171,7 +167,7 @@ XmlRpcSocket::accept(XmlRpcSocket::Socket fd)
 }
 
 
-    
+
 // Connect a socket to a server (from a client)
 bool
 XmlRpcSocket::connect(XmlRpcSocket::Socket fd, std::string& host, int port)
@@ -215,7 +211,7 @@ XmlRpcSocket::getPort(XmlRpcSocket::Socket socket)
 
 
 // Returns last errno
-int 
+int
 XmlRpcSocket::getError()
 {
 #if defined(_WINDOWS)
@@ -227,14 +223,14 @@ XmlRpcSocket::getError()
 
 
 // Returns message corresponding to last errno
-std::string 
+std::string
 XmlRpcSocket::getErrorMsg()
 {
   return getErrorMsg(getError());
 }
 
 // Returns message corresponding to errno... well, it should anyway
-std::string 
+std::string
 XmlRpcSocket::getErrorMsg(int error)
 {
   char err[60];
